@@ -94,24 +94,6 @@ def pressure_field(positions,frequencies,
         directivity_points, theta = define_arc(directivity_distance,num_directivity_points)
         directivity = np.abs(get_field(positions,frequencies,strengths,velocities,areas,phases,directivity_points,time,method))
         directivity = directivity / np.max(directivity)
-
-    # if method == "Rayleigh":
-        
-        
-    
-    # elif method == "Monopole Addition":
-        
-    #     if not directivity_only:
-    #         pressure_field = get_field(positions,frequencies,strengths,velocities,phases,field_points,time)
-    #         pressure_field = pressure_field.reshape(-1,len(x))
-    #     else:
-    #         pressure_field = 0
-        
-    #     # Getting the directivity at a given distance. Default is 1000 meters away
-    #     if not dimensions == 1:
-    #         directivity_points, theta = define_arc(directivity_distance,num_directivity_points)
-    #         directivity = np.abs(get_field(positions,frequencies,strengths,velocities,phases,directivity_points,time))
-    #         directivity = directivity / np.max(directivity)
     
     # Only show plots if you calculated the entirie pressure field
     if dimensions == 1:
@@ -395,85 +377,6 @@ def get_field(positions,frequencies,strengths,velocities,areas,phases,field_poin
             
     return responses
 
-"""
-Perform Rayleigh Integration
-"""
-
-# def rayleigh(positions,areas,velocities,phases,field_points,frequencies,time):
-    
-#     # Convert everything to a numpy array
-#     positions = np.asarray(positions)
-#     areas = np.asarray(areas)
-#     velocities = np.asarray(velocities)
-#     phases = np.asarray(phases)
-#     field_points = np.asarray(field_points)
-
-#     if len(positions[0]) == 2 and len(field_points[0]) == 1:
-#         new_points = np.zeros([len(field_points),2])
-#         for i in range(len(field_points)):
-#             new_points[i] = np.array([field_points[i,0],0.0])
-#         field_points = new_points
-
-#     if len(positions[0]) == 3 and len(field_points[0]) == 1:
-#         new_points = np.zeros([len(field_points),3])
-#         for i in range(len(field_points)):
-#             new_points[i] = np.array([field_points[i,0],0.0,0.0])
-#         field_points = new_points
-
-#     if len(positions[0]) == 3 and len(field_points[0]) == 2:
-#         new_points = np.zeros([len(field_points),3])
-#         for i in range(len(field_points)):
-#             new_points[i] = np.array([field_points[i,0],field_points[i,1],0.0])
-#         field_points = new_points
-    
-#     # Initialize the responses
-#     responses = np.zeros([len(field_points),len(velocities)], dtype = complex)
-    
-#     # Define constants
-#     c = 343 # Phase speed in air
-#     rho_0 = 1.2 # Density of air
-
-#     # Creating Early Mesh Grids. This creates some that only need to be created once
-#     distances = np.zeros([len(field_points),len(velocities)])
-#     for i in range(len(velocities)):
-#         distances[:,i] = la.norm(field_points - positions[i,:],axis = 1)
-
-#     FREQUENCIES, _ = np.meshgrid(frequencies,distances[:,0])
-#     PHASES, _ = np.meshgrid(frequencies,distances[:,0])
-#     VELOCITIES, _ = np.meshgrid(velocities,distances[:,0])
-#     AREAS, _ = np.meshgrid(areas,distances[:,0])
-
-#     print(AREAS)
-    
-#     for i in range(len(velocities)):
-
-#         omegas = 2 * np.pi * FREQUENCIES
-#         k = omegas/c
-
-#         responses = responses + (1j * omegas * rho_0 / (2 * np.pi) * 
-#                                 VELOCITIES * 
-#                                 np.exp(-1j * k * distances)/distances * 
-#                                 np.exp(1j*PHASES) * np.exp(1j*omegas*time) * 
-#                                 AREAS)
-
-#     # Each column represents the contribution to a point by a particular source. We must sum them up at each point
-#     responses = np.sum(responses,axis = 1)
-            
-#     return responses
-
-"""
-Get the distance between two 2D points
-"""
-def get_distance(source_point,field_point):
-
-    if len(source_point) == 3 and len(field_point) == 1:
-        field_point = np.array([field_point[0],0.0,0.0])
-
-    if len(source_point) == 3 and len(field_point) == 2:
-        field_point = np.array([field_point[0],field_point[1],0.0])
-
-    return la.norm(field_point - source_point)
-
 """
 Define an arc for whatever reasons you may want to do so
 """
